# oneNeuron_pypi

oneNeuron_pypi

## How to use:
```python
from oneNeuron_pypi.perceptron import Perceptron

# Get X and y first and then use below mentioned commands
model = Perceptron(eta=ETA, epochs=EPOCHS)
model.fit(X, y)

```

## References

[Official python docs](https://packaging.python.org/tutorials/packaging-projects)

[Other references](https://docs.github.com/en/actions/automating-builds-and-tests/building-and-testing-python#publishing-to-package-registries)
